@@ -43,26 +43,31 @@ class UsersRepository(Repository):
     def get_user_settings(self, user_id):
         return self.users_store.fetch_user_settings(user_id)
 
-    def get_notifications(self, items_count):
-        return self.users_store.fetch_notifications(items_count)
+    def get_notifications(self):
+        return self.users_store.fetch_notifications()
 
-    def add_notification(self, user_id, user_name, user_email, expression_to_evaluate, check_every_seconds,
-                         check_times, is_active, channel_type, fields_to_send, source_id):
+    def add_notification(self, user_id, user_name, user_email, notification_type, check_every,is_active,
+                         start_date, end_date, channel_type, threshold_value, source_id):
         n = user_notification(
-            user_id=user_id, user_name=user_name, user_email=user_email, expression_to_evaluate=expression_to_evaluate,
-            check_every_seconds=check_every_seconds, check_times=check_times, is_active=is_active,
-            channel_type=channel_type, fields_to_send=fields_to_send, source_id=source_id,
+            user_id=user_id, user_name=user_name, user_email=user_email,
+            notification_type=notification_type,
+            check_every=check_every,
+            start_date=start_date,
+            end_date=end_date,
+            is_active=is_active,
+            channel_type=channel_type, threshold_value=threshold_value, source_id=source_id,
             operation=OPERATIONS.ADDED.name)
         self.memories[USER_NOTIFICATIONS_MEMORY_KEY].items.append(n)
         return n
 
-    def edit_notification(self, in_id, user_id, user_name, user_email, expression_to_evaluate, check_every_seconds,
-                          check_times, is_active, channel_type, fields_to_send, source_id):
+    def edit_notification(self, in_id, user_id, user_name, user_email, notification_type, check_every,
+                          start_date,end_date, is_active, channel_type, threshold_value, source_id):
         n = user_notification(
             id=in_id,
-            user_id=user_id, user_name=user_name, user_email=user_email, expression_to_evaluate=expression_to_evaluate,
-            check_every_seconds=check_every_seconds, check_times=check_times, is_active=is_active,
-            channel_type=channel_type, fields_to_send=fields_to_send, source_id=source_id,
+            user_id=user_id, user_name=user_name,
+            user_email=user_email, notification_type=notification_type,
+            check_every=check_every, start_date=start_date, end_date=end_date, is_active=is_active,
+            channel_type=channel_type, threshold_value=threshold_value, source_id=source_id,
             operation=OPERATIONS.MODIFIED.name)
         self.memories[USER_NOTIFICATIONS_MEMORY_KEY].items.append(n)
         return n
